pub enum ExecApprovalRequirement {
Skip {
bypass_sandbox: bool,
proposed_execpolicy_amendment: Option<ExecPolicyAmendment>,
},
NeedsApproval {
reason: String,
proposed_execpolicy_amendment: Option<ExecPolicyAmendment>,
proposed_network_policy_amendments: Vec<NetworkPolicyAmendment>,
},
Forbidden {
reason: String,
},
}Expand description
The approval requirement determined by the execution policy engine.
Variants
Skip
Execution is allowed without approval.
Fields

proposed_execpolicy_amendment: Option<ExecPolicyAmendment>Optional proposed policy amendment (e.g., to persist the allowed prefix).
NeedsApproval
Execution is allowed but requires human approval first.
Fields

proposed_execpolicy_amendment: Option<ExecPolicyAmendment>Optional proposed policy amendment that would be applied on approval.

proposed_network_policy_amendments: Vec<NetworkPolicyAmendment>Proposed network policy amendments that would be applied on approval.
Forbidden
Execution is forbidden by policy.
Implementations